==> cesium-fabric%2B1.21.8-0.2.6-sources.jar: de/yamayaki/cesium/mixin/core/chunks/MixinChunkMap.java <==
package de.yamayaki.cesium.mixin.core.chunks;

import com.mojang.datafixers.DataFixer;
import de.yamayaki.cesium.api.accessor.DatabaseSetter;
import de.yamayaki.cesium.api.accessor.DatabaseSource;
import de.yamayaki.cesium.api.database.IDBInstance;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.concurrent.Executor;
import java.util.function.Supplier;
import net.minecraft.class_10592;
import net.minecraft.class_1255;
import net.minecraft.class_2794;
import net.minecraft.class_2823;
import net.minecraft.class_32;
import net.minecraft.class_3218;
import net.minecraft.class_3485;
import net.minecraft.class_3898;
import net.minecraft.class_3949;
import net.minecraft.class_4153;
import net.minecraft.class_5567;

@Mixin(class_3898.class)
public class MixinChunkMap {
    @Shadow
    @Final
    private class_4153 poiManager;

    @Inject(method = "<init>", at = @At("RETURN"))
    private void setCesiumDB(class_3218 serverLevel, class_32.class_5143 levelStorageAccess, DataFixer dataFixer, class_3485 structureTemplateManager, Executor executor, class_1255 blockableEventLoop, class_2823 lightChunkGetter, class_2794 chunkGenerator, class_3949 chunkProgressListener, class_5567 chunkStatusUpdateListener, Supplier supplier, class_10592 ticketStorage, int i, boolean bl, CallbackInfo ci) {
        IDBInstance database = ((DatabaseSource) serverLevel).cesium$getStorage();

        ((DatabaseSetter) this.poiManager)
                .cesium$setStorage(database);

        ((DatabaseSetter) this)
                .cesium$setStorage(database);
    }
}

==> cesium-fabric%2B1.21.10-0.2.6-sources.jar: de/yamayaki/cesium/mixin/core/chunks/MixinChunkMap.java <==
package de.yamayaki.cesium.mixin.core.chunks;

import com.mojang.datafixers.DataFixer;
import de.yamayaki.cesium.api.accessor.DatabaseSetter;
import de.yamayaki.cesium.api.accessor.DatabaseSource;
import de.yamayaki.cesium.api.database.IDBInstance;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.concurrent.Executor;
import java.util.function.Supplier;
import net.minecraft.class_10592;
import net.minecraft.class_1255;
import net.minecraft.class_2794;
import net.minecraft.class_2823;
import net.minecraft.class_32;
import net.minecraft.class_3218;
import net.minecraft.class_3485;
import net.minecraft.class_3898;
import net.minecraft.class_4153;
import net.minecraft.class_5567;

@Mixin(class_3898.class)
public class MixinChunkMap {
    @Shadow
    @Final
    private class_4153 poiManager;

    @Inject(method = "<init>", at = @At("RETURN"))
    private void setCesiumDB(class_3218 serverLevel, class_32.class_5143 levelStorageAccess, DataFixer dataFixer, class_3485 structureTemplateManager, Executor executor, class_1255 blockableEventLoop, class_2823 lightChunkGetter, class_2794 chunkGenerator, class_5567 chunkStatusUpdateListener, Supplier supplier, class_10592 ticketStorage, int i, boolean bl, CallbackInfo ci) {
        IDBInstance database = ((DatabaseSource) serverLevel).cesium$getStorage();

        ((DatabaseSetter) this.poiManager)
                .cesium$setStorage(database);

        ((DatabaseSetter) this)
                .cesium$setStorage(database);
    }
}
